# 지정한 경로에 error.log 파일을 생성하고 에러 로그를 기록하는 모듈
import os
from .common_task import CommonLuigiTask
from functools import wraps

def handle_exceptions(func):
    @wraps(func)
    def wrapper(self:CommonLuigiTask, *args, **kwargs):
        try:
            return func(self, *args, **kwargs)
        except Exception as e:
            write_log(self.output_dir(), f"{self.__class__.__name__}: {e}")
            print(f"Error: {e}")
            raise e
    return wrapper

def write_log(path, message):
    """
    지정한 경로에 error.log 파일을 생성하고 에러 로그를 기록하는 함수
    :param path: 로그 파일을 생성할 경로
    :param message: 기록할 에러 메시지
    """
    with open(os.path.join(path, 'error.log'), 'a') as f:
        f.write(message + '\n')


import luigi
import os
import json

class CommonLuigiTask(luigi.Task):
    """
    Ex:
    config = {
        "output_dir": "output/ababab"
    }
    luigi.build([ShelveSetTask(config = config)], 
                local_scheduler=True)

    """
    def result_key(self) -> str:
        return f"{self.__class__.__name__.lower()}"

    def output(self):
        """ 별도로 정의하지 않으면  클래스이름(소문자).json 이 결과 파일이 된다. 
        """
        file_path = os.path.join(self.output_dir(), self.result_key() + ".json")
        return luigi.LocalTarget(file_path)

    def work_file_path(self, file_name):
        file_path = os.path.join(self.config.get('output_dir'), file_name)
        return luigi.LocalTarget(file_path).path

    def write_output(self, all_info):
        with self.output().open('w') as f:
            json.dump(all_info, f, indent=4)

    def get_output_from_path(self, file_name: str) -> dict | list | None :
        path = self.work_file_path(file_name)
        with open(path,'r') as f:
            pv = json.load(f)
        return pv

    def get_previous_output(self) -> dict | list | None:
        with self.input().open('r') as f:
            pv = json.load(f)
        return pv
    
    def output_dir(self):
        return self.config.get('output_dir','')




from setuptools import setup, find_packages

setup(
    name="luigino",
    version="0.1.4",
    author="Jung JinYoung",
    author_email="bungker@gmail.com",
    description="Utilities package for Luigi tasks with Celery integration",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/jyjung/luigino",
    packages=find_packages(),
    install_requires=[
        "luigi",
        "celery",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)